import java.util.*;

class SomeObject {
        private int counter;
        private static SomeObject instance = new SomeObject();
        private final Object lock = new Object();

        public void changeValue() {
                synchronized(lock) {
                        counter += 1;
                }
        }

        public int getValue() {
                synchronized(lock) {
                        return counter;
                }
        }

        public static SomeObject lookup(String name) {
                if("SomeObject".equals(name)) {
                        return instance;
                }
                return null;
        }

        private SomeObject() {}
}

class TrustedThread implements Runnable {

        private int id;
        private static final SomeObject someObject = SomeObject.lookup("SomeObject");

        public TrustedThread(int id) {
                this.id = id;
        }

        @Override
        public void run() {
                while(true) {
                        System.out.println("Thread: "+id+" counter: "+someObject.getValue());
                        someObject.changeValue();
                }
        }
} 

class UntrustedThread extends TimerTask {
        @Override
        public void run() {
                SomeObject someObject = SomeObject.lookup("SomeObject");
                synchronized(someObject) {
                        System.out.println("The fun is over :-)");
                        while(true) {
                                try {
                                        Thread.sleep(Integer.MAX_VALUE);
                                } catch(InterruptedException exception) {
                                        exception.printStackTrace();
                                }
                        }
                }
        }
}

public class Safe {
        public static void main(String[] args) {
                Timer timer = new Timer();
                timer.schedule(new UntrustedThread(),10_000);
                new Thread(new TrustedThread(1)).start();
                new Thread(new TrustedThread(2)).start();
                new Thread(new TrustedThread(3)).start();
        }
}
